@@ -1,23 +1,35 @@
-#'Wrapper for applying the climdex routine  ETCCDI climate change indices to n-dimensional arrays.
+#'Wrapper for applying the climdex routine  ETCCDI climate change indices to 
+#'n-dimensional arrays.
 #'
-#'@description This function computes the t90p, t10p, cdd or rx5day indices from n-dimensional arrays.
+#'@description This function computes the t90p, t10p, cdd or rx5day indices from 
+#'n-dimensional arrays.
 #'
-#'@param data A numeric n-dimensional array containing daily maximum or minimum temperature, wind speed or precipitation amount.
-#'@param metric The metric to be computed, either 't90p', 't10p', 'Wx', 'cdd' or 'rx5day'.
-#'@param threshold For the 't90p' and 't10p' metrics, an array of the 90th/10th percentiles must be included. This parameter can be computed with the \code{Threshold} function.
-#'@param base.range The years used for the reference period. If NULL (by default), all years are used.
-#'@param dates A vector of dates with a calendar attributes. If NULL (by default), the 'time' attributes of parameter 'data' are considered.
-#'@param timedim An integer number indicating the position of the time dimension in the parameter \code{data}. If NULL (by default), the dimension called 'time' in parameter \code{data} is considered as temporal dimension.
+#'@param data A numeric n-dimensional array containing daily maximum or minimum 
+#'  temperature, wind speed or precipitation amount.
+#'@param metric The metric to be computed, either 't90p', 't10p', 'Wx', 'cdd' or 
+#'  'rx5day'.
+#'@param threshold For the 't90p' and 't10p' metrics, an array of the 90th/10th 
+#'  percentiles must be included. This parameter can be computed with the 
+#'  \code{Threshold} function.
+#'@param base.range The years used for the reference period. If NULL 
+#'  (by default), all years are used.
+#'@param dates A vector of dates with a calendar attributes. If NULL 
+#'  (by default), the 'time' attributes of parameter 'data' are considered.
+#'@param timedim An integer number indicating the position of the time dimension 
+#'  in the parameter \code{data}. If NULL (by default), the dimension called 
+#'  'time' in parameter \code{data} is considered as temporal dimension.
 #'@param calendar A character indicating the calendar type.
 #'@param ncores The number of cores to be used when computing the index.
 #'
 #'@return A list of length 2:
 #'\itemize{
-#'  \item\code{$result} {An array with the same dimensions as the input array, except for the temporal dimension which is renamed to 'year', moved to the first dimension position and reduce to annual resolution.}
-#'  \item\code{$years}  {A vector of the corresponding years.}}
+#'  \item\code{$result} {An array with the same dimensions as the input array, 
+#'  except for the temporal dimension which is renamed to 'year', moved to the 
+#'  first dimension position and reduce to annual resolution.}
+#'  \item\code{$years}  {A vector of the corresponding years.}
+#'}
 #'
 #'@import multiApply
-#'@import climdex.pcic
 #'@import PCICt
 #'@examples 
 #'##Example synthetic data:
@@ -35,8 +47,10 @@
 #'          seq(ISOdate(1909, 1, 1), ISOdate(1909, 1, 31), "day"),
 #'          seq(ISOdate(1910, 1, 1), ISOdate(1910, 1, 31), "day"),
 #'          seq(ISOdate(1911, 1, 1), ISOdate(1911, 1, 31), "day"))
-#'metadata <- list(time = list(standard_name = 'time', long_name = 'time',  calendar = 'gregorian', 
-#'                             units = 'days since 1970-01-01 00:00:00', prec = 'double', 
+#'metadata <- list(time = list(standard_name = 'time', long_name = 'time', 
+#'                             calendar = 'gregorian', 
+#'                             units = 'days since 1970-01-01 00:00:00', 
+#'                             prec = 'double', 
 #'                             dim = list(list(name = 'time', unlim = FALSE))))
 #'attr(time, "variables") <- metadata
 #'attr(data, 'Variables')$dat1$time <- time
@@ -45,15 +59,15 @@
 #'dim(thres) <- c(jdays = 31, lon = 2, lat = 3,  model = 1)
 #'str(thres)
 #'
-#'
 #'clim <- Climdex(data, metric = "t90p", threshold = thres)
 #'str(clim)
 #'@references David Bronaugh for the Pacific Climate Impacts Consortium (2015).
 #'  climdex.pcic: PCIC Implementation of Climdex Routines. R package
 #'  version 1.1-6. http://CRAN.R-project.org/package=climdex.pcic
 #'@export
-Climdex <- function(data, metric, threshold = NULL, base.range = NULL, dates = NULL, timedim = NULL, 
-                    calendar = NULL, ncores = NULL) {
+Climdex <- function(data, metric, threshold = NULL, base.range = NULL, 
+                    dates = NULL, timedim = NULL, calendar = NULL, 
+                    ncores = NULL) {
   if (is.null(data) | is.null(metric)) {
     stop("Parameters 'data' and 'metric' cannot be NULL.")
   }
