@@ -1,40 +1,58 @@
 #'Heat and cold waves duration for n-dimensional arrays
 #'
-#'This function computes the duration of a heat/cold wave as the number of consecutive days for which the maximum/minimum temperature is exceeding/below a threshold over a minimum number of days in month or seasonal resolution.
+#'This function computes the duration of a heat/cold wave as the number of 
+#'consecutive days for which the maximum/minimum temperature is exceeding/below 
+#'a threshold over a minimum number of days in month or seasonal resolution.
 #'
-#'@param data A numeric n-dimensional array containing daily maximum or minimum temperature 
-#'@param threshold An array with the threshold to be/not to be reach, usually given by the 90th/10th percentiles for heat/cold waves computed with the \code{Threshold} function.
-#'@param op A character ">" (by default) or ">=" for heat waves and "<" or "<=" for cold waves indicating the operator must be used  to compare data to threshold.
-#'@param spell.length A number indicating the number of consecutive days with extreme temperature to be considered heat or cold wave.
-#'@param by.seasons If TRUE (by default), the wave duration is computed for each season (DJF/MAM/JJA/SON) separately. If FALSE is specified, the monthly wave duration is computed.
-#'@param dates A vector of dates including calendar attributes. If NULL (by default), the 'time' attributes of parameter 'data' is used.
+#'@param data A numeric n-dimensional array containing daily maximum or minimum 
+#'  temperature 
+#'@param threshold An array with the threshold to be/not to be reach, usually 
+#'  given by the 90th/10th percentiles for heat/cold waves computed with the 
+#'  \code{Threshold} function.
+#'@param op A character ">" (by default) or ">=" for heat waves and "<" or "<=" 
+#'  for cold waves indicating the operator must be used  to compare data to 
+#'  threshold.
+#'@param spell.length A number indicating the number of consecutive days with 
+#'  extreme temperature to be considered heat or cold wave.
+#'@param by.seasons If TRUE (by default), the wave duration is computed for each 
+#'  season (DJF/MAM/JJA/SON) separately. If FALSE is specified, the monthly wave 
+#'  duration is computed.
+#'@param dates A vector of dates including calendar attributes. If NULL (by 
+#'  default), the 'time' attributes of parameter 'data' is used.
 #'@param calendar A character indicating the calendar type.
 #'@param ncores The number of cores to be used when computing the wave duration.
 #'
 #'@return A list of length 2:
 #'  \itemize{
-#'  \item\code{$result}{An array with the same dimensions as the input \code{data}, but with the time dimension reduce from daily to monthly or seasonal resolution depending on the selected resolution in \code{by.season}.}
-#'  \item\code{$years}{A vector of the years and season/months corresponding to the resolution selected in \code{by.season} and temporal length of the input \code{data}}}
+#'  \item\code{$result}{An array with the same dimensions as the input 
+#'  \code{data}, but with the time dimension reduce from daily to monthly or 
+#'  seasonal resolution depending on the selected resolution in \code{by.season}.}
+#'  \item\code{$years}{A vector of the years and season/months corresponding to 
+#'  the resolution selected in \code{by.season} and temporal length of the input 
+#'  \code{data}}}
 #'
 #'@import multiApply   
 #'@import PCICt
-#'@import climdex.pcic
 #'@examples
 #'##Example synthetic data:
 #'data <- 1:(2 * 3 * 31 * 5)
 #'dim(data) <- c(lon = 2, lat = 3, time = 31, model = 5)
-#'time <- as.POSIXct(paste(paste(1900, 1, 1:31, sep = "-"), paste(12, 0, 0.0, sep = ":")), tz = "CET")
-#'metadata <- list(time = list(standard_name = 'time', long_name = 'time', calendar = 'standard', 
+#'time <- as.POSIXct(paste(paste(1900, 1, 1:31, sep = "-"), paste(12, 0, 0.0, 
+#'                   sep = ":")), tz = "CET")
+#'metadata <- list(time = list(standard_name = 'time', long_name = 'time', 
+#'                 calendar = 'standard', 
 #'                 units = 'days since 1970-01-01 00:00:00', prec = 'double', 
 #'                 dim = list(list(name ='time', unlim = FALSE))))
 #'attr(time, "variables") <- metadata                 
 #'attr(data, 'Variables')$dat1$time <- time
 #'threshold <- rep(40, 31)
 #'
-#'a <- WaveDuration(data, threshold, op = ">", spell.length = 6, by.seasons = TRUE, ncores = NULL)
+#'a <- WaveDuration(data, threshold, op = ">", spell.length = 6, 
+#'                  by.seasons = TRUE, ncores = NULL)
 #'str(a)
 #'@export
-WaveDuration <- function(data, threshold, op = ">", spell.length = 6, by.seasons = TRUE, dates = NULL, 
+WaveDuration <- function(data, threshold, op = ">", spell.length = 6, 
+                         by.seasons = TRUE, dates = NULL, 
                          calendar = NULL, ncores = NULL) {
   if (is.null(data) | is.null(threshold)) {
     stop("Parameter 'data' and 'threshold' cannot be NULL.")
@@ -203,7 +221,8 @@ WaveDuration <- function(data, threshold, op = ">", spell.length = 6, by.seasons
                     op = op, spell.length = spell.length, ncores = ncores)
   } else {
     result <- list()
-    result$output1 <- .WaveDuration(data = data[[1]], threshold = data[[2]], date.factor = date.factor, 
+    result$output1 <- .WaveDuration(data = data[[1]], threshold = data[[2]], 
+                                    date.factor = date.factor, 
                                     jdays = jdays, op = op, spell.length = spell.length)
   }
   if (length(years) > 1) {
@@ -225,7 +244,8 @@ WaveDuration <- function(data, threshold, op = ">", spell.length = 6, by.seasons
 .WaveDuration <- function(data, threshold, date.factor = date.factor,
                           jdays = jdays,  op = op, spell.length = spell.length) {
   result <- threshold.exceedance.duration.index(daily.temp = data, 
-                                                date.factor = date.factor, jdays = jdays,
+                                                date.factor = date.factor, 
+                                                jdays = jdays,
                                                 thresholds = threshold,
                                                 op = op, min.length = spell.length, 
                                                 spells.can.span.years = TRUE, 1)
